pub struct ZOptional<T: VldSchema> { /* private fields */ }Expand description
Wraps a schema to make it optional.
If the value is null or missing, returns Ok(None).
Otherwise, delegates to the inner schema and wraps the result in Some.
Implementations